@@ -1,3 +1,5 @@
+from copy import deepcopy
+
 from asgiref.sync import async_to_sync
 from channels.layers import get_channel_layer
 from django.dispatch import Signal
@@ -19,10 +21,11 @@ class Observer(BaseObserver):
         message = self.serialize(signal, *args, **kwargs)
         channel_layer = get_channel_layer()
         for group_name in self.group_names_for_signal(*args, message=message, **kwargs):
-            async_to_sync(channel_layer.group_send)(group_name, message)
+            message_to_send = deepcopy(message)
+            message_to_send["group"] = group_name
+            async_to_sync(channel_layer.group_send)(group_name, message_to_send)
 
     def group_names(self, *args, **kwargs):
         yield "{}-{}-signal".format(
-            self._stable_observer_id,
-            self.func.__name__.replace("_", ".")
+            self._stable_observer_id, self.func.__name__.replace("_", ".")
         )
